==> ejc-ztpcdc-impl-3.0.0-20230505.055326-10-sources.jar: com/ejianc/business/basem/service/impl/ActRuTaskService.java <==
package com.ejianc.business.basem.service.impl;

import com.ejianc.business.basem.bean.ActRuTaskPo;
import com.ejianc.business.basem.service.IActRuExecutionService;
import com.ejianc.business.basem.utils.ToolUtil;
import com.ejianc.business.basem.mapper.ActRuTaskMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @Classname ActRuExecutionService
 * @Description TODO
 * @Date 2023/4/27 15:33
 * @Created by lijunxue
 */
@Service("actRuTaskService")
public class ActRuTaskService implements IActRuExecutionService {

    @Autowired
    private ActRuTaskMapper actRuTaskMapper;


    /**
     * 根据业务id获取到当前节点的类型
     * @param businessKey
     * @return
     */
    public String getNodeType(String businessKey) {
        List<ActRuTaskPo> actRuTaskPos = actRuTaskMapper.selectByBizKey(businessKey);
        if (ToolUtil.isNotEmpty(actRuTaskPos) && actRuTaskPos.size() == 1) {
            return actRuTaskPos.get(0).getDescription();
        } else {
            // 有多个说明 可能出现不同的情况
            return "ERROR";
        }
    }

    /**
     * 根据业务id 在会签的时候 获取到还有多少节点的任务没有完成
     *
     * @param businessKey
     * @return
     */
    public List<String> getListNodeType(String businessKey) {
        List<ActRuTaskPo> actRuTaskPos = actRuTaskMapper.selectByBizKey(businessKey);
        if (ToolUtil.isNotEmpty(actRuTaskPos) && actRuTaskPos.size() > 1) {
            List<String> collect = actRuTaskPos.stream().map(ActRuTaskPo::getDescription).collect(Collectors.toList());
            return collect;
        } else {
            return Arrays.asList("ERROR");
        }
    }

}

==> ejc-ztpcdc-impl-3.0.0-20230829.023503-203-sources.jar: com/ejianc/business/basem/service/impl/ActRuTaskService.java <==
package com.ejianc.business.basem.service.impl;

import com.ejianc.business.basem.bean.ActRuTaskPo;
import com.ejianc.business.basem.service.IActRuExecutionService;
import com.ejianc.business.basem.utils.ToolUtil;
import com.ejianc.business.basem.mapper.ActRuTaskMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @Classname ActRuExecutionService
 * @Description TODO
 * @Date 2023/4/27 15:33
 * @Created by lijunxue
 */
@Service("actRuTaskService")
public class ActRuTaskService implements IActRuExecutionService {

    @Autowired
    private ActRuTaskMapper actRuTaskMapper;


    /**
     * 根据业务id获取到当前节点的类型
     * @param businessKey
     * @return
     */
    public String getNodeType(String businessKey) {
        List<ActRuTaskPo> actRuTaskPos = actRuTaskMapper.selectByBizKey(businessKey);
        if (ToolUtil.isNotEmpty(actRuTaskPos) && actRuTaskPos.size() == 1) {
            return actRuTaskPos.get(0).getDescription();
        } else {
            // 有多个说明 可能出现不同的情况
            return "ERROR";
        }
    }

    /**
     * 根据业务id获取到当前节点的类型（多个）
     * @param businessKey
     * @return
     */
    public List<ActRuTaskPo> getNodeTypes(String businessKey) {
        List<ActRuTaskPo> actRuTaskPos = actRuTaskMapper.selectByBizKey(businessKey);
        if (ToolUtil.isNotEmpty(actRuTaskPos)) {
            return actRuTaskPos;
        }
        return null;
    }

    /**
     * 根据业务id 在会签的时候 获取到还有多少节点的任务没有完成
     *
     * @param businessKey
     * @return
     */
    public List<String> getListNodeType(String businessKey) {
        List<ActRuTaskPo> actRuTaskPos = actRuTaskMapper.selectByBizKey(businessKey);
        if (ToolUtil.isNotEmpty(actRuTaskPos) && actRuTaskPos.size() > 1) {
            List<String> collect = actRuTaskPos.stream().map(ActRuTaskPo::getDescription).collect(Collectors.toList());
            return collect;
        } else {
            return Arrays.asList("ERROR");
        }
    }

}
